@@ -1,5 +1,10 @@
 from numba import jit
 
+ifunc = {
+    "dunkin": {"love": 1, "rayleigh": 2},
+    "fast-delta": {"love": 1, "rayleigh": 3},
+}
+
 
 def jitted(*args, **kwargs):
     """Custom :func:`jit` with default options."""
