@@ -1,6 +1,7 @@
 from collections import namedtuple
 
 from ._base import BaseDispersion
+from ._common import ifunc
 from ._surf96 import surf96
 
 __all__ = [
@@ -15,15 +16,9 @@ DispersionCurve = namedtuple(
 )
 
 
-ifunc = {
-    "dunkin": {"love": 1, "rayleigh": 2},
-    "fast-delta": {"love": 1, "rayleigh": 3},
-}
-
-
 class PhaseDispersion(BaseDispersion):
     def __init__(
-        self, thickness, velocity_p, velocity_s, density, algorithm="dunkin", dc=0.005
+        self, thickness, velocity_p, velocity_s, density, algorithm="dunkin", dc=0.005,
     ):
         """
         Phase velocity dispersion class.
@@ -64,7 +59,7 @@ class PhaseDispersion(BaseDispersion):
         Returns
         -------
         namedtuple
-            Dispersion curve as a namedtuple (period, velocity, mode, type).
+            Dispersion curve as a namedtuple (period, velocity, mode, wave, type).
 
         Note
         ----
@@ -98,7 +93,7 @@ class GroupDispersion(BaseDispersion):
         density,
         algorithm="dunkin",
         dc=0.005,
-        dt=0.005,
+        dt=0.025,
     ):
         """
         Group velocity dispersion class.
@@ -119,11 +114,12 @@ class GroupDispersion(BaseDispersion):
              - 'fast-delta': fast delta matrix (after Buchen and Ben-Hador, 1996).
         dc : scalar, optional, default 0.005
             Phase velocity increment for root finding.
-        dt : scalar, optional, default 0.005
+        dt : scalar, optional, default 0.025
             Frequency increment (%) for calculating group velocity.
 
         """
         super().__init__(thickness, velocity_p, velocity_s, density, algorithm, dc)
+
         self._dt = dt
 
     def __call__(self, t, mode=0, wave="rayleigh"):
@@ -142,7 +138,7 @@ class GroupDispersion(BaseDispersion):
         Returns
         -------
         namedtuple
-            Dispersion curve as a namedtuple (period, velocity, mode, type).
+            Dispersion curve as a namedtuple (period, velocity, mode, wave, type).
 
         Note
         ----
@@ -179,6 +175,7 @@ class GroupDispersion(BaseDispersion):
         )
 
         idx = c2 > 0.0
+        t = t[idx]
         t1 = 1.0 / t1[idx]
         t2 = 1.0 / t2[idx]
         c = (t1 - t2) / (t1 / c[idx] - t2 / c2[idx])
